@@ -2,7 +2,7 @@
 
   scsi_admin: proc.c
 
-  Copyright 2001 by Andreas H. Mueller <andreas.muller@web.de>
+  Copyright 2001, 2002, 2005 Kadir A. Mueller <kadir.mueller@theflatnet.de>
 
   This program is free software; you may redistribute and/or modify it under
   the terms of the GNU General Public License Version 2 as published by the
@@ -18,6 +18,13 @@
 
 #include "global.h"
 
+
+extern int added;
+extern int bus, id, lun, chan;
+extern int fd;
+extern char *ownname;
+
+
 int proc_add_single_device()
 {
 	FILE *procfile;
